import request from '@/utils/request'


const url = '/yiZhuLuRu'

// 下面是 api 请求
export function getMyPatient() {
    return request({
        url: url + '/getMyPatient',
        method: 'get',
    })
}

export function getOrderNo() {
    return request({
        url: url + '/getOrderNo',
        method: 'get',
    })
}

export function enterOrders(data) {
    return request({
        url: url + '/enterOrders',
        method: 'post',
        data
    })
}

export function insertTemplateOrder(data) {
    return request({
        url: url + '/insertTemplateOrder',
        method: 'post',
        data
    })
}

export function stopOrder(data) {
    return request({
        url: url + '/stopOrder',
        method: 'post',
        data
    })
}

export function toDeleteAnOrder(orderNo) {
    return request({
        url: url + '/toDeleteAnOrder',
        method: 'get',
        params: {orderNo}
    })
}

export function deleteMultipleOrders(data) {
    return request({
        url: url + '/deleteMultipleOrders',
        method: 'post',
        data
    })
}


export function voidOrders(orderNo, reasonForCancellation) {
    return request({
        url: url + '/voidOrders',
        method: 'get',
        params: {orderNo, reasonForCancellation}
    })
}


export function confirmOrders(data) {
    return request({
        url: url + '/confirmOrders',
        method: 'post',
        data
    })
}


export function getParentOrders(patNo, times) {
    return request({
        url: url + '/getParentOrders',
        method: 'get',
        params: {patNo, times},
    })
}


export function huoQuHuanZheXinXi(inpatientNo) {
    return request({
        url: url + '/huoQuHuanZheXinXi',
        method: 'get',
        params: {inpatientNo},
    })
}

export function huoQuYiZhuMingCheng(inpatientNo, admissTimes, orderName) {
    return request({
        url: url + '/huoQuYiZhuMingCheng',
        method: 'get',
        params: {inpatientNo, admissTimes, orderName},
    })
}

export function huoQuGeRenPinLv(patNo, times) {
    return request({
        url: url + '/huoQuGeRenPinLv',
        method: 'get',
        params: {patNo, times}
    })
}


export function huoQuYiZhuShuJu(data) {
    return request({
        url: url + '/huoQuYiZhuShuJu',
        method: 'post',
        data,
    })
}

export function huoQuXiangMu(code, groupNo) {
    return request({
        url: url + '/huoQuXiangMu',
        method: 'get',
        params: {code, groupNo},
    })
}

export function huoQuFeiYongXinXi(queryCode) {
    return request({
        url: url + '/huoQuFeiYongXinXi',
        method: 'get',
        params: {queryCode},
    })
}

export function huoQuZhuYuanPinLv(code) {
    return request({
        url: url + '/huoQuZhuYuanPinLv',
        method: 'get',
        params: {code},
    })
}

export function huoQuGeiYaoFangShi(code) {
    return request({
        url: url + '/huoQuGeiYaoFangShi',
        method: 'get',
        params: {code},
    })
}

export function getCostFreeDosing(code) {
    return request({
        url: url + '/getCostFreeDosing',
        method: 'get',
        params: {code},
    })
}

export function huoQuZhiXinKeShi(code) {
    return request({
        url: url + '/huoQuZhiXinKeShi',
        method: 'get',
        params: {code},
    })
}

export function shangChuanYiZhu(data) {
    return request({
        url: url + '/shangChuanYiZhu',
        method: 'post',
        data,
    })
}

export function huoQuYiZhuMuBan(code, deptCode, muBanLeiXing, currentPage, total) {
    return request({
        url: url + '/huoQuYiZhuMuBan',
        method: 'get',
        params: {code, deptCode, muBanLeiXing, currentPage, total},
    })
}

export function getDoctorSOrderTemplateMaxSortNo() {
    return request({
        url: url + '/getDoctorSOrderTemplateMaxSortNo',
        method: 'get',
    })
}

export function huoQuMuBanShuJu(code) {
    return request({
        url: url + '/huoQuMuBanShuJu',
        method: 'get',
        params: {code},
    })
}


export function deleteADoctorSOrderTemplate(patternCode) {
    return request({
        url: url + '/deleteADoctorSOrderTemplate',
        method: 'delete',
        params: {patternCode}
    })
}

export function collectDoctorSOrderTemplate(patternCode) {
    return request({
        url: url + '/collectDoctorSOrderTemplate',
        method: 'get',
        params: {patternCode}
    })
}

export function muBanCaoZuo(patternCode, patternName, deptCode, sortNo, flag) {
    return request({
        url: url + '/muBanCaoZuo',
        method: 'get',
        params: {patternCode, patternName, deptCode, sortNo, flag},
    })
}

export function expensesForGettingADoctorSOrder(patNo, times) {
    return request({
        url: url + '/expensesForGettingADoctorSOrder',
        method: 'get',
        params: {patNo, times},
    })
}

export function singleDataCheck(data) {
    return request({
        url: url + '/singleDataCheck',
        method: 'post',
        data: data
    })
}


export function saveTemplate(data) {
    return request({
        url: url + '/saveTemplate',
        method: 'post',
        data: data
    })
}


export function doesTheTemplateExist(name) {
    return request({
        url: url + '/doesTheTemplateExist',
        method: 'get',
        params: {name}
    })
}

export function saveTheThirdLevelDoctor(data) {
    return request({
        url: url + '/saveTheThirdLevelDoctor',
        method: 'post',
        data: data
    })
}

export function associateOrdersApi(data) {
    return request({
        url: url + '/associateOrders',
        method: 'post',
        data: data
    })
}

export function confirmTheDoctorSOrderWithMedicine(patNo, times) {
    return request({
        url: url + '/confirmTheDoctorSOrderWithMedicine',
        method: 'get',
        params: {patNo, times}
    })
}

